otel_shelf library

OpenTelemetry instrumentation for package:shelf.

Functions

otelShelfMiddleware({Tracer? tracer, bool errorStatusBuilder(int statusCode)?}) → Middleware
Returns a shelf Middleware that opens a SERVER span per incoming request.
runWithoutShelfInstrumentation<T>(T body()) → T
Runs body with shelf instrumentation suppressed.
runWithoutShelfInstrumentationAsync<T>(Future<T> body()) Future<T>
Async variant of runWithoutShelfInstrumentation: runs body with shelf instrumentation suppressed until its future completes.
shelfInstrumentationSuppressed() bool
Whether shelf instrumentation is suppressed in the current Zone.